package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````-!@!`#0```!PD0````0`!30`(``)
M`"@`'``;``$``'"\AP``O(<!`+R'`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0#(AP``R(<```4`````$```
M`0```,B-``#(G0$`R)T!`%`"``!T`@``!@`````0```"````[(T``.R=`0#L
MG0$`"`$```@!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DR(T`
M`,B=`0#(G0$`.`(``#@"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`!SL27FT02Z'!/@D738V%LYSK:NL$
M````$`````$```!'3E4```````,````"`````````$,````%````(`````H`
M``"(`A```$01``````!6`'`8@@``,`@@$!$"`!`"`"@````H```02`(@"@`*
M`(2$0JA```%@80"$"!I"-),``0`()%B`!(E@#),X`$)*0$0`0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@$!``@F`#$"(`D$((L`@!`D`D``D#I-&0``````%
M````!P`````````)````"@````T````/````$````!$````3````%P```!D`
M`````````````!L`````````'@```!\`````````(0```"(````D````````
M`"D````J`````````"L````L````+@```#`````Q`````````#(`````````
M,P```#8````W````.0```#L````]````/@```$````!"````10```$<```!)
M````2P```$\```!0````40```%(```!3````5````%4```!7````6```````
M``!;````7````%X``````````````&$```!B````9`````````"B`O89"XH0
M5\C5LG&CX/M)*]#A(LY*KO^B6N^0GR+'J'SM$0_[H6Q@.?*+',T_#*]NQ=\?
M?9`0Z:Q+X\`\K3D-Z/O#PNT_D`)V;^-P!Z2'_ZQP#J\!(_FD:AJ>4!;J6O$O
M3CWV>_!*:T)F2Q"!=((-?ZF<FY!U@@TA8F0'AO"6?%COEWG`Y!F7SMY'+5^6
MDQP;G]:]%8PES#-BV^VR`8MO[2SVB^)'Q@&_VE<;Q;F<0&=9+^7#Y3\L0$V=
M?$+ZUX>GFY,<!3*EA5#N$>/MWI,<+L6;MIDBU&BFW:-KB0=PTW=4/)0,+;Q%
M+0ZQ<PPZEPN93\.;AOF<@9R[DQS'#N`]8)CO$MOW`%XLW_Y(/WZ6?&+0^H)K
M"4/6)'6"#3Z>0D16DEI2;WII^N\+4?EK?YI\0T75["'_Y`Y9.T`?WX4@3])1
M!(359-1\R3E`'^"G`@KV(\X@N^.2?+W02WTPN((-41M]7[J5DQP`KS3HPXZ'
M__/;TQW\TN\/9Z_,9MEQ6!P``````````````````````0``````````````
M(````!```````````````"`````L```````````````@````8P``````````
M````%@```!L!`````````````!(```#&````**`!``$````1`!@`^@```'@3
M`0``````$@```(<$``!@)`$`A`0``!(`#0"S`0`````````````2````P@,`
M````````````$@```*L!`````````````!(```!"`@`````````````2````
MV`(`````````````$@```%8$``!L*P$`Z````!(`#0"``@``(*`!``0````1
M`!@`W@(`````````````$@```,L#``#@-`$`!`$``!(`#0!4````````````
M```2````UP,``)1%`0`$````$0`/`'0!`````````````!(```"B````````
M```````2````-`$`````````````$@```*,"`````````````!(```"K`@``
M```````````2````U`$`````````````$@```,<"`````````````!(```"F
M`P``%$0!`%0!```2``T`L@(`````````````$@```%X"`````````````!(`
M``!-`0``+!0!```````2````^0$`````````````$@```(<"````````````
M`!(```"P`P``2"L!`"0````2``T`N0(`````````````$@````(#``#0G0$`
M!````!$`%`#I```````````````2````%`0``#R@`0``````$``8`'`"````
M`````````!(```!"!```5"P!```&```2``T`P`(`````````````$@```.,!
M`````````````!(````T!```.$(!`(@````2``T`[`,``#08`0``````$@`-
M`'8#``#D*`$`?````!(`#0!H`0`````````````2````4P,``/`B`0`P````
M$@`-`!P$```\H`$``````!``&`#F`@``&*`!``0````1`!@`"@(`````````
M````$@````P$``"8'P$`.````!(`#0#_`0`````````````2`````00``,!"
M`0!4`0``$@`-`+T!`````````````!(````_`0`````````````2````4`(`
M````````````$@```.L!`````````````!(```!"`P``N"`!``0````2``T`
MY```````````````$@```.@"```8H`$`!````"$`&`!U!```%*`!``0````1
M`!<`\P,``!B@`0``````$``8`"`"`````````````!(```!&````````````
M```2````Z`,```"@`0``````(``7`'\$``!@*0$`5````!(`#0!V````.!0!
M```````2````\@$`````````````$@```#H"`````````````!(```#-`0``
M```````````2````Q`$`````````````$@```"L!`````````````!(```"F
M`0`````````````2````>P$`````````````$@```.8#````H`$``````!``
M%P"5`@`````````````2````E@``````````````$@```.X`````````````
M`!(```#P`@`````````````2````,0(`````````````$@```&L"````%@$`
M-`(``!(`#0!/!```&*`!```````0`!<`:`0``+P@`0`T`@``$@`-`-,`````
M`````````!(```"W```````````````2````70$`````````````$@```&`#
M``!4,@$`C`(``!(`#0"5`0`````````````2````A`,``-`?`0#H````$@`-
M`-P!`````````````!(````]!```/*`!```````0`!@`AP``````````````
M$@```)P"`````````````!(````-`0`````````````2````C@(`````````
M````$@```!T$```\H`$``````!``&``9`@`````````````2````A@$``-B=
M`0`3````$0`4``0"`````````````!(```":`P``(",!`$`!```2``T`*`0`
M`!B@`0``````$``8``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)4
M34-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y
M<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L
M7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!0
M97)L7VYE=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T
M9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R
M;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E
M<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,
M7VUE;6]R>5]W<F%P`%]?<W1A8VM?8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E
M861D:7(V-`!S=')D=7``8VQO<V5D:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK
M`&UE;6UO=F4`<W1R=&]K`'-T<FQE;@!R;61I<@!R96%D`&UK9&ER`%]?=F9P
M<FEN=&9?8VAK`&=E='!I9`!?7VQS=&%T-C1?=&EM938T`')E861L:6YK`')E
M86QL;V,`7U]S<')I;G1F7V-H:P!?7V9P<FEN=&9?8VAK`%]?;&EB8U]S=&%R
M=%]M86EN`%]?<W1A=#8T7W1I;64V-`!S=&1E<G(`;65M8VAR`'-T<F-H<@!M
M96UC;7``;65M<V5T`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`<W1R
M8VUP`%]?97)R;F]?;&]C871I;VX`86)O<G0`<W1R;F-M<`!?7V5N=FER;VX`
M7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS
M;RXU+C0P`&QI8F,N<V\N-@!L9"UL:6YU>"UA<FUH9BYS;RXS`'!A<E]C=7)R
M96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN=&5R;F%L<U]005)?0D]/5`!P
M87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M
M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L
M96%N=7``7TE/7W-T9&EN7W5S960`7U]D871A7W-T87)T`%]?8G-S7W-T87)T
M7U\`<VAA7W5P9&%T90!X<U]I;FET`%]?96YD7U\`7U]B<W-?96YD7U\`7U]B
M<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A
M<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I
M90!P87)?:6YI=%]E;G8`1TQ)0D-?,BXT`$=,24)#7S(N,S0``````0`!``$`
M`0`!``$``0`!``(``@`"``(``@`!``(``@`!``$``0`"``$``0`"``(``@`"
M``$``@`#``$``@`"``$``@`$``(``0`#``$``@`"``$``0`!``$``0`!``(`
M`@`!``(``0`"``$``@`"``$``0`"``$``0`#``$``0`!``$``@`"``(``@`!
M``(``0`!``(``0`!``(``@`!``$``0`!``$``0`!``(``0`"``$``0`"``$`
M`@`!``(``0`"``$``0`!``$`+@,``!`````@````%&EI#0``!`"4!```````
M``$``@`D`P``$`````````"TD98&```#`)X$```0````%&EI#0```@"4!```
M`````/2?`0`5`0``^)\!`!,$``#0G0$`%",``-B=`0`480``&*`!`!0P```@
MH`$`%`\``"B@`0`4!@```)\!`!9B```$GP$`%CH```B?`0`6#0``#)\!`!87
M```0GP$`%DL``!2?`0`63```&)\!`!95```<GP$`%@<``""?`0`6`0``))\!
M`!9>```HGP$`%CX``"R?`0`61P``,)\!`!8%```TGP$`%EP``#B?`0`670``
M/)\!`!89``!`GP$`%DD``$2?`0`6&```2)\!`!8D``!,GP$`%C,``%"?`0`6
M'```5)\!`!8_``!8GP$`%AX``%R?`0`60@``8)\!`!93``!DGP$`%EL``&B?
M`0`60P``;)\!`!99``!PGP$`%B(``'2?`0`6"@``>)\!`!94``!\GP$`%D4`
M`("?`0`6,0``A)\!`!8V``"(GP$`%D8``(R?`0`6)@``D)\!`!8U``"4GP$`
M%DT``)B?`0`6"P``G)\!`!84``"@GP$`%E<``*2?`0`6-P``J)\!`!8X``"L
MGP$`%A\``+"?`0`6*0``M)\!`!9.``"XGP$`%A4``+R?`0`68```P)\!`!8M
M``#$GP$`%D\``,B?`0`6"0``S)\!`!8,``#0GP$`%A```-2?`0`6%@``V)\!
M`!9$``#<GP$`%A(``."?`0`6'0``Y)\!`!8@``#HGP$`%B@``.R?`0`62```
M\)\!`!8:```(0"WI6@$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[EU(L```#&C^((
MRHSBU/N\Y0#&C^((RHSBS/N\Y0#&C^((RHSBQ/N\Y0#&C^((RHSBO/N\Y0#&
MC^((RHSBM/N\Y0#&C^((RHSBK/N\Y0#&C^((RHSBI/N\Y0#&C^((RHSBG/N\
MY0#&C^((RHSBE/N\Y0#&C^((RHSBC/N\Y0#&C^((RHSBA/N\Y0#&C^((RHSB
M?/N\Y0#&C^((RHSB=/N\Y0#&C^((RHSB;/N\Y0#&C^((RHSB9/N\Y0#&C^((
MRHSB7/N\Y0#&C^((RHSB5/N\Y0#&C^((RHSB3/N\Y0#&C^((RHSB1/N\Y0#&
MC^((RHSB//N\Y0#&C^((RHSB-/N\Y0#&C^((RHSB+/N\Y0#&C^((RHSB)/N\
MY0#&C^((RHSB'/N\Y0#&C^((RHSB%/N\Y0#&C^((RHSB#/N\Y0#&C^((RHSB
M!/N\Y0#&C^((RHSB_/J\Y0#&C^((RHSB]/J\Y0#&C^((RHSB[/J\Y0#&C^((
MRHSBY/J\Y0#&C^((RHSBW/J\Y0#&C^((RHSBU/J\Y0#&C^((RHSBS/J\Y0#&
MC^((RHSBQ/J\Y0#&C^((RHSBO/J\Y0#&C^((RHSBM/J\Y0#&C^((RHSBK/J\
MY0#&C^((RHSBI/J\Y0#&C^((RHSBG/J\Y0#&C^((RHSBE/J\Y0#&C^((RHSB
MC/J\Y0#&C^((RHSBA/J\Y0#&C^((RHSB?/J\Y0#&C^((RHSB=/J\Y0#&C^((
MRHSB;/J\Y0#&C^((RHSB9/J\Y0#&C^((RHSB7/J\Y0#&C^((RHSB5/J\Y0#&
MC^((RHSB3/J\Y0#&C^((RHSB1/J\Y0#&C^((RHSB//J\Y0#&C^((RHSB-/J\
MY0#&C^((RHSB+/J\Y0#&C^((RHSB)/J\Y0#&C^((RHSB'/J\Y0#&C^((RHSB
M%/J\Y0#&C^((RHSB#/J\Y0#&C^((RHSB!/J\Y0#&C^((RHSB_/F\Y0#&C^((
MRHSB]/F\Y0'*H.-P0"WI#,!-X-`/C.4@T$WBW#&?Y10`C>40$(WE#""-Y1`0
MC>(,((WB%`"-X@`PD^4<,(WE`#"@X]W__^NT(9_EM`&?Y0(0H.')"P#KK#&?
MY0!`T^4``%3C0@``"J`QG^7!"P#K%%"=Y0,PG^<#()#G!`"%X@<!<./6,]+E
M`U"%X@,P@^/6,\+E40``B@`!H.&R___K;"&?Y6Q!G^40$)WE#,"2Y10@G>4`
MX)'E7&&?Y0$`4N,`,*#A!`"$Y5`!G^4$8(/E`."#Y0C`@^4,`(/E0@``V@0`
M0>("`8#@#,"#X@3@L>4!`%#A!."LY?O__QH#$(+B``"@XP``C>4%(*#A`0&#
MYPP1G^4,`)3E%?__ZP``4.,?```*#`"4Y6+__^L8$(WB`%"@X>P`G^5]``#K
M``!0XQH```H,`)3E^O[_ZS7__^NH,)_E`""3Y1PPG>4"(#/@`#"@XR0``!H%
M`*#A(-"-XG"`O>@<___KF""?Y0``4.,,`(+E&@``"C+__^N8,)_E>`L`ZP,P
MG^<#,)#GAD;#Y;#__^H,`)3E`/__Z]S__^H(`)3E``!0XP$```I)!P#KW___
MZF0`G^48$(WB6```ZP``4.,(`(3EV?__"O;__^I,$)_E3`"?Y5G__^L$$*#C
MPO__Z@$`H.-\___K0O__Z]"=`0!X$P$`.!0!`"B@`0"$B0``"*`!`"R@`0!(
M20$`3$D!`!0?`0#L1@$`9(@``(A&`0#8G0$`B$@!``"PH.,`X*#C!!"=Y`T@
MH.$$("WE!``MY1R@G^48,(_B`Z"*X``PH.,$,"WE#`"?Y0``FN=5___KLO[_
MZX2&```(`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!N_[_ZFR&`````0``
M&`"?Y1@PG^4``%/A'O\O`1`PG^4``%/C'O\O`1/_+^$8H`$`&*`!```````D
M`)_E)#"?Y0`P0^"C'Z#A0Q&!X,$0L.$>_R\!$#"?Y0``4^,>_R\!$_\OX1B@
M`0`8H`$``````!!`+>D80)_E`##4Y0``4^,0@+T8X/__ZP$PH.,`,,3E$("]
MZ"F@`0#F___J`<J@X_!'+>D,P$W@X`^,Y0"`4.(J```*M#"?Y0"0D^4``%GC
M*```"@!0V.4!<*#A``!5XST`51,!4*`3`%"@`Q$``!H`0)GE``!4XPP```H)
M8*#A!2"@X0@0H.$$`*#A`/__ZP``4.,"```:!3#4YST`4^,+```*!$"VY0``
M5./S__\:!`"@X?"'O>@(4*#A`3#UY0``4^,]`%,3^___&@A01>#F___J"6!&
MX`%0A>)&8:#A!4"$X`0`H.$`8(?E\(>]Z`A`H.'M___J"4"@X>O__^H8H`$`
M`<J@XQ!`+>D,P$W@@`^,Y70PG^5XT$WB#1"@X0!`H.$`,)/E=#"-Y0`PH.-9
M_O_K``!0XP``H!,$```:$#"=Y0\Z`^(*"E/C`0E3$P<```HT,)_E`""3Y70P
MG>4"(#/@`#"@XP<``!IXT(WB$("]Z`(0H.,$`*#A9/[_ZQ`/;^&@`J#A\?__
MZIS^_^O0G0$``<J@X_!`+>D,P$W@:`^,Y4`QG^6$T$WB`&!0X@`PD^5\,(WE
M`#"@XP(```H`,-;E``!3XP<``!H8,9_E`""3Y7PPG>4"(#/@`#"@XT```!J$
MT(WB\("]Z!7^_^L`0%#B]/__"@0`H.&>_O_K``!0XRD```H3,-#E$U"`XBX`
M4^,"```:`3#5Y0``4^/T__\*$S#0Y2X`4^,D```*!@"@X4C^_^L`<*#A!0"@
MX47^_^L``(?@`@"`XFG^_^N8,)_E`"#@XP$0H.,$4(WE`&"-Y0!PH.&&_O_K
M"!"-X@<`H.%3_O_K`0!PXP<`H.$#```*&#"=Y0\Z`^(!"5/C$@``"C/^_^L'
M`*#A%O[_ZP0`H.%T_O_K``!0X]7__QH$`*#A0/[_ZP8`H.%9_O_KP?__Z@$P
MU>4N`%/CU___&@(PU>4``%/CQO__"M/__^JK___KZ___ZD7^_^O0G0$`*$8!
M``'*H./P1RWI#,!-X-@/C.4`,-'E`4"@X>`AG^4]`%/C`4"!`@C03>(`4*#A
M!`"@X0`@DN4$((WE`""@XPG^_^L-$*#A`&"@X04`H.$Y___K`)!0XCP```H"
M_O_K``!6X3,``)H`<)WEE(&?Y0=QH.$`,-7E``!3XST`4Q,!,*`3`#"@`P4`
M``H%,*#A`2#SY0``4N,]`%(3^___&@4P0^`"`(;B`P"`X`!@F.44_O_K``!0
MXP<`AN<5```*`""8Y04`H.$!,-#D!Q"2YST`4^,``%,3`##!Y08```H!(('B
M`3#0Y`(0H.$]`%/C``!3$P$PPN3Y__\:`2"@X3TPH.,`,,'E`3#4Y```4^,!
M,.+E^___&N0PG^4`()/E!#"=Y0(@,^``,*#C,P``&@C0C>+PA[WH`9!)X@$P
MU.0``%/C`3#IY?O__QKQ___JL("?Y0!PF.4`,)?E``!3XR,```H',*#A!""S
MY0D0H.$``%+C`9")XOK__QH#$('B`1&@X8`PG^4`()/E``!2XP\``!H!(*#C
M`0"@X0`@@^78_?_K`*!0XMK__PH'$*#A"7&@X0<@H.'A_?_K`*"(Y0"0C>4!
MD(GB`#"@XPDQBN>G___J!P"@X??]_^L``%#C`*"@X0``B.7*__\*"7&@X?+_
M_^H#D*#A"!"@X^#__^K#_?_KT)T!`!B@`0`LH`$``<J@XW!`+>D,P$W@``",
MY1@`#.4!VDWB"-!-XMPPG^4`8*#A`0J-X@0`@.(`,)/E`#"`Y0`PH./$()_E
MQ`"?Y0%0H.$$$(WBR/W_ZP!`4.('``#:`2!$X@@PC>(",(/@!#!3Y0``4^,4
M```:``!2XQ$``!J0,)_EO`D`ZP4@H.$#,)_G!A"@X0,`D.=._?_K`1J-XF0P
MG^4$$('B`""3Y0`PD>4"(#/@`#"@XQ(``!H!VHWB"-"-XG"`O>@"0*#A!""@
MX2\0H.,$`(WBO_W_ZP``4./F__\*,!"?Y:,)`.L$,*#A`1"?YP0@C>(!`)#G
M!A"@X63]_^OD___J@/W_Z]"=`0#_#P``,$8!`'"!```,@0```<J@XS!`+>D,
MP$W@Z`^,Y4Q0G^4,T$WBCPD`ZP50G^<`0*#A/#"?Y3P@G^4\$)_E!0"0YY3]
M_^LT`)_E-#"?Y0#`H.,``)_G+""?Y2P0G^4``)3G"!"-Z#3]_^L,T(WB,("]
MZ,"```#HA@$`+!0!`$!&`0"8@```1$D!`%0R`0!<1@$`$$`MZ7,)`.L80)_E
M&#"?Y1@@G^4$0)_G%!"?Y00`D.<00+WH=_W_ZD2```#HA@$`+!0!`$!&`0`!
MRJ#C,$`MZ0S`3>```(SE`<I,X@``C.4H``SE`MI-XAS03>*L,)_E`AJ-XA00
M@>(`,)/E`#"!Y0`PH.-1_?_KE,"?Y90PG^64()_E`1"@XP$0C>@,`(WB5OW_
MZP$:C>(!*J#C$!"!X@P`C>)+_?_K`$!0X@!0H+,)``"Z`0"$XBC]_^L`4%#B
M!0``"@$:C>($(*#A$!"!X@']_^L`,*#C!##%YP(:C>(H,)_E%!"!X@`@D^4`
M,)'E`B`SX``PH.,#```:!0"@X0+:C>(<T(WB,("]Z!;]_^O0G0$`@$8!`'1&
M`0`!$```Q/__Z@'*H./P1RWI#,!-X```C.6H``SE0MU-X@C03>+T,9_E0LV-
MX@!0H.$!8*#AZ`&?Y1`0C>($P(SB`#"3Y0`PC.4`,*#C"?[_ZR\0H.,`0*#A
M!0"@X9[\_^L``%#C#@``"K@!G^4%$*#ALO[_ZP4`H.%"'8WBG#&?Y000@>(`
M()/E`#"1Y0(@,^``,*#C8```&D+=C>((T(WB\(>]Z`8`H.'<_/_K>!&?Y>S\
M_^L`D%#BZO__"@`PV>5H@9_E:'&?Y0``4^-889_E.@``"@``5.,$```*"1"@
MX00`H.$/_?_K``!0XRL```H)`*#AJ_S_ZP$@0.("((G@`@!9X0`PH.$`H*#A
M`#"),``0H#,!`(DR`P``.@@``.H#`%#A`!##Y0(```H!('/E+P!2X_G__PH)
M`*#AF?S_ZP"@H.$%`*#AEOS_ZPH`@.`!`(#B`0I0X\+__RH',*#A`2J@XP$0
MH..$`(WB"%"-Y02`C>4`D(WEU?S_ZQ`0C>*$`(WBHOS_ZP``4.,#```:(#"=
MY0\Z`^(""5/C$P``"@80H.$``*#CKOS_ZP"04.*L__\*`##9Y0``4^/$__\:
M``!4XP(```H`,-3E+@!3XP(```I<D)_E`:"@X]C__^H!,-3E``!3X^S__PKX
M___J`1"@XX0`C>)8_/_K``!0X^;__QH<`)_EA!"-XDO^_^N$`(WB@?S_ZY;_
M_^J+_/_KT)T!`(A&`0"41@$`I$8!`+!&`0"H1@$`A$8!``'*H.,00"WI#,!-
MX/@/C.4O$*#C`$"@X3+\_^L``%#C`4"`$@0`H.$00+WH;/S_Z@'*H.-P0"WI
M#,!-X```C.48``SE`=I-X@C03>(!&HWB$#&?Y0!04.($$('B`#"3Y0`P@>4`
M,*#C+@``"@`PU>4``%/C*P``"CO\_^L!((#B`0I2XP!`H.$S``"*!&"-X@40
MH.$&`*#A.?S_ZP$P1.(#,(;@`P!6X0D``"H$`(;@!2"-X@`0H.,"``#J`@!0
MX0`0P.4"```*`3!PY2\`4^/Y__\*+Q"@XP8`H.$!_/_K``!0XP\```H&`%#A
M`#"@@P`PP(4&`*#A.?S_ZP$:C>)@,)_E!!"!X@`@D^4`,)'E`B`SX``PH.,1
M```:`=J-X@C0C>)P@+WH`1J-XC0PG^4$$('B`""3Y0`PD>4"(#/@`#"@XP8`
M`!H<`)_E`=J-X@C0C>)P0+WH(?S_Z@``H./E___J*OS_Z]"=`0"$1@$``<J@
MXS!`+>D,P$W@Z`^,Y2`TG^4,T$WB'$2?Y1Q4G^4`,)/E!#"-Y0`PH.,-$*#A
M!`"@X23]_^L``%#C#```"@`0G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$
M,(/B!""3Y0``4N,$((/D^___&NW__^K(0Y_EP%.?Y0T0H.$$`*#A$/W_ZP``
M4.,,```*`!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2
MXP0@@^3[__\:[?__ZGQ#G^5P4Y_E#1"@X00`H.'\_/_K``!0XPP```H`$)WE
M`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM
M___J,$.?Y2!3G^4-$*#A!`"@X>C\_^L``%#C#```"@`0G>4`()7E`3&"X`0`
MD^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^KD0I_ET%*?
MY0T0H.$$`*#AU/S_ZP``4.,,```*`!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G
M\___"@0P@^($()/E``!2XP0@@^3[__\:[?__ZIA"G^6`4I_E#1"@X00`H.'`
M_/_K``!0XPP```H`$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@
MD^4``%+C!""#Y/O__QKM___J3$*?Y3!2G^4-$*#A!`"@X:S\_^L``%#C#```
M"@`0G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D
M^___&NW__^H`0I_EX%&?Y0T0H.$$`*#AF/S_ZP``4.,,```*`!"=Y0`@E>4!
M,8+@!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:[?__ZK1!
MG^6049_E#1"@X00`H.&$_/_K``!0XPP```H`$)WE`""5Y0$Q@N`$`)/E``!0
MXP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J:$&?Y4!1G^4-$*#A
M!`"@X7#\_^L``%#C#```"@`0G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$
M,(/B!""3Y0``4N,$((/D^___&NW__^H<09_E\%"?Y0T0H.$$`*#A7/S_ZP``
M4.,,```*`!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2
MXP0@@^3[__\:[?__Z@T0H.',`)_E2OS_ZP`04.(!```*L`"?Y?C\_^L-$*#A
MM`"?Y4/\_^L`$%#B`0``"J@`G^7Q_/_K#1"@X:``G^4\_/_K`!!0X@P```IP
M`)_EZOS_ZT@PG^4`()/E!#"=Y0(@,^``,*#C#```&G00G^5$`)_E#-"-XC!`
MO>C?_/_J#1"@X6``G^4J_/_K`!!0XN___PHL`)_EV/S_Z^S__^H:^__KT)T!
M`+1&`0`8H`$`P$8!`,A&`0#41@$`W$8!`.Q&`0"(1@$`^$8!``1'`0`01P$`
ME$8!`!Q'`0`P1P$`1$<!`%!'`0!T1P$`8$<!``'*H.,$X"WE#,!-X/`/C.5<
M,)_E#-!-XE@`G^4-$*#A`#"3Y00PC>4`,*#C!?S_ZP``4.,%```*``#0Y0``
M4.,P`%`3`0"@`P``H!,!`"#B'#"?Y0`@D^4$,)WE`B`SX``PH.,!```:#-"-
MX@3PG>3J^O_KT)T!`/A&`0`!RJ#C#P`MZ03@+>4,P$W@\`^,Y3`0G^4,T$WB
M+,"?Y0``D>44,(WB$""=Y0$0H.,`P)SE!,"-Y0#`H.,`,(WEO_K_Z_\`H.,.
M^__K(*`!`-"=`0``P*#C\$,MZ0'HH.,,P$W@#N!,X`'*3.(``(SE#@!<X?O_
M_QHX``[E`=A-XAS03>("$*#C`!"-Y0'HC>(\$9_E`""@XP`PH.,`$)'E%!".
MY0`0H.,4X([B`)"@X;7Z_^L!8%#B`(#!XL@OH.'(/R;@`C!3X',P_^8","/@
M`C!3X`(@PN`#8%;@`H#(X```6.,R``"ZZ'"?Y0Q0C>(`$*#C!B"@X0@PH.$)
M`*#A`!"-Y:#Z_^L!`''C`0!P`RP```K`()_E!1"@X0D`H.%@^O_K`0!PXR0`
M``H'`%#C&@``F@@`0.(`0)7@`P``.A8``.H!0$3B!0!4X1,``#H((*#C!Q"@
MX00`H.$D^O_K``!0X_;__QH%0$3@!@"4X,0?J.`!R(WB5#"?Y13`C.(`()/E
M`#"<Y0(@,^``,*#C#@``&@'8C>(<T(WB\(.]Z`%H5N(`@,CB`0!XXP$(=@/.
M__\:``#@XP`0H.'L___J&`"?Y8W__^L4`)_EB___ZW/Z_^O0G0$`"*`!``@`
M`0"(1P$`>$<!``'*H.,00"WI#,!-X/@/C.4D^O_K1_K_ZP``4.,``)`5$("]
MZ`'*H.-P0"WI#,!-X-@/C.7`,)_E&-!-X@!0H.$0$(WBM`"?Y0`PD^44,(WE
M`#"@XV+[_^L`0%#B`@``"@`PU.4``%/C"@``&H@PG^4`()/E%#"=Y0(@,^``
M,*#C!1"@`70`GP4:```:&-"-XG!`O>@$_/_J!0"@X1SZ_^L`8*#A!`"@X1GZ
M_^L``(;@`@"`XCWZ_^M$P)_E1#"?Y0`@X.,!$*#C"$"-Y2`0C>@`8*#A6?K_
MZQPPG^4`()/E%#"=Y0(@,^``,*#C!A"@`0@`GP7D__\*+_K_Z]"=`0"41P$`
MI$8!`*A&`0`!RJ#C\$\MZ0S`3>#H#HSEB#6?Y8@EG^7TT$WB`""2Y>P@C>4`
M(*#C`&"@X0<`D^B(4(WB#$"#XB3`@^('`(7HH."-X@\`M.B4<(WB#P"NZ`,`
ME.@#`([H!P"<Z`<`A^@8$(WB/`6?Y1K[_^L`0%#B`@``"@`PU.4``%/C^@``
M&L7Y_^OH^?_K``!0XV\```H`@)#E``!8XVP```H(`*#AV/G_ZX``H.$!`(#B
M_/G_ZP#`V.4``%SC`$"@X0!PH.$*```*X)2?Y00`H.$`P(WE"3"@X0`@X.,!
M$*#C%/K_ZP'`^.4"0(3B``!<X_7__QJX!)_EH("-X@(``.H$`+CE``!0XPT`
M``H8$(WB\?K_ZP!`4.+X__\*`##4Y0``4^/U__\*(?O_ZP``4./R__\*!`"@
MX='Y_^L`0%#B#```&@1`E>0``%3C"0``"@`PU.4``%/CM0``"@0`H.$3^__K
M``!0X_'__QH$0)7D``!4X_7__QH$`*#AHOG_ZS"4G^4`H*#A!P"@X9[Y_^L`
MH(K@`:N*X@2@BN(*`*#AP/G_ZQ`TG^4`(.#C`1"@XP@PC>4,<(WE`#2?Y0!`
MC>4$D(WE`("@X=KY_^L'':#C"`"@X3[Y_^L!`'#C`P``&N_Y_^L`$)#E$0!1
MXY8``!H8$(WB"`"@X5/Y_^L`4%#B)P``"K@3G^4`,);EM".?Y0``D>4!$*#C
M`("-Y:?Y_^L`<*#C?#.?Y0`@D^7L,)WE`B`SX``PH./6```:!P"@X?30C>+P
MC[WHC?G_ZP"`4.)Y```:!`"7Y```4.,)```*&!"-XISZ_^L`,%#B^/__"@`P
MT^4``%/C\O__&@0`E^0``%#C]?__&@T`H..%^?_K-(.?Y5/`H.,`0*#A`'"@
MX8C__^HH,)WE#SH#X@$)4^/3__\:,$"=Y3CY_^L``%3AS___&B@PG>6#.Z#A
MHSN@X0<-4^/*__\:"@"@X7'Y_^L8$(WB`'"@X>`"G^5Z^O_K`!!0XF@```H`
M`);E6OS_ZP"@4.)D```*"@"@X3[Y_^L#`%#C`$"@X0L``)H$`$#BK!*?Y0``
MBN"7^?_K``!0XP4``!H$`%3CB```"@1`BN`%,%3E+P!3XX0```J$`I_E&!"-
MXF#Z_^L``%#C`P``"@`PT.4P`%/C``!3$P0``!H*`*#A`!"@XS+Y_^L`0%#B
M1P``&E`2G^5(`I_E!/O_ZUSY_^M$8I_E1#*?Y0`@X.,!$*#C\(#-X0Q@C>4T
MHI_E"`"-Y0<`H.%>^?_K#@``ZG?Y_^L`,)#E$0!3XQ```!I,^?_K`1"@XP%0
MA>`*,*#A!""@X1!@C>4,4(WE`,"@X0<`H.$`$XWH3OG_ZP<=H.,'`*#ALOC_
MZP$`<.,`0*#AZO__"@@`H.'C^/_KB`&?Y0<0H.'>^O_K!P"@X;K^_^M[___J
M`T"@X4[__^KR^/_K@`"@X0$`@.(8___J<`&?Y0`PEN60(9_E``"0Y000C>4`
M@(WE`1"@XQ3Y_^MK___JJ?[_ZRPQG^4`()/E[#"=Y0(@,^``,*#C0@``&@0`
MH.'TT(WB\$^]Z/GX_^H`H);EF/__ZB[^_^L`H%'B`&"@X;/__[H*(%#B`+"@
MXP`PRN($`*#A`+"-Y?/X_^L&(*#CN!"-X@0`H.&V^/_K!@!0XRT``!H$,9_E
MN""=Y0,`4N&C__\:O"O=X?0PG^4#`%+AG___&C(@5N(`,,KB!`"@X0"PC>7@
M^/_K!`"@X<!`C>(H(*#C!!"@X:+X_^LH`%#C&0``&J0@G^6X,)_E#""-Y0$0
MH.,`(.#C!P"@X0A`C>7P@,WAZ+#-Y?;X_^NL___J!$"6Y0``5.-W__\*!`"@
MX:7X_^L#`%#C<___F@0`0.)T$)_E``"$X/_X_^L``%#C!*"@`6S__^K%^/_K
M7`"?Y=K]_^OTA@$`T)T!`(A&`0"L1P$`1$<!`+!&`0#`1P$`M$<!`""@`0`$
M2`$`I$<!`%A(`0!@2`$`^$8!`'1'`0!$20$`C$@!`)Q(`0#(1P$``$-!0TA%
M``!\2`$`:$@!`'!(`0`!RJ#C<$`MZ0S`3>#H#XSE)"*?Y0C03>(@,I_E`""2
MY00@C>4`(*#CNP0`ZP,PG^<-$*#A`T"0YP0"G^5H,-3E:3#$Y:/Y_^L``%#C
M`@``"@`PT.4Q`%/C80``"FK\_^O@,9_EK`0`ZP,PG^<#0)#G!`"@X=`1G^4#
M,*#C`2"@XS;X_^L`0%#B#0``"KPQG^40()3EH`0`ZP,PG^<`$)+E`%"@X:@A
MG^4#`)#G,?C_ZQ`PE.4`$)/E"#"1Y0$%$^-2```:C"&?Y9,$`.N($9_E`B"?
MYP!0H.$#,*#C`@"0YP$@H.,=^/_K`$!0X@H```IH`9_E#1"@X7;Y_^L`(%#B
M.P``"E@QG^40$)3E`S"?YP`0D>4#`)7G%OC_ZT11G^5$,9_E?`0`ZT`1G^4#
M,)_G`$"@X0$@H.,#8)#G!@"@X?'W_^LH(9_E`!"@X08`H.$(^/_K'#&?Y0`@
MH.,8`9_E`S"?YPT0H.$#,)3G:2##Y5CY_^L``%#C`$"@X0@`A>4/```*!QV@
MXP0`H.'/]__K`2"`XA$`4.,!`%(3`#"@X2```(J0,)_E`""3Y00PG>4"(#/@
M`#"@XQD``!H(T(WB<("]Z`0`E>4,_O_K``!0XP!`H.$(`(7EZ?__&IP`G^5$
M^/_K`3#0Y0``4^.?__\*F?__ZFQ0G^40()3E!#"5Y0``DN4`$)/E9_K_Z\/_
M_^IL,)_E`S"?YP,`E><:^/_KI___ZB'X_^L$()7E5`"?Y0`0DN4$(*#A+OC_
MZ]"=`0!P;0``W$8!`#1M``"P2`$`!&T``+1(`0#,;```O$@!`)1&`0"0;```
M+*`!`'!L``#`2`$`V$@!`#QL``"(1@$`X$@!`(AK```$20$``<J@XS!`+>D,
MP$W@Z`^,Y>`PG^4,T$WB`$"@X0T0H.'4`)_E`#"3Y00PC>4`,*#C!?G_ZP`P
M4.(*```*`##3Y0``4^,P`%,3`3"@`P`PH!,!,"/B``!4XP`PH`,!,`,2``!3
MXP<``!J(,)_E`""3Y00PG>4"(#/@`#"@XQP``!H,T(WB,("]Z``PU.4``%/C
M]/__"@0`H.%H^__K+Q"@XP!0H.&3]__K``!0XP%0@!(%`*#ASO?_ZT`0G^4$
M(*#C^_?_ZP``4./F__\:)#"?Y0`@D^4$,)WE`B`SX``PH.,#```:!`"@X0S0
MC>(P0+WH+_G_ZLKW_^O0G0$`^$8!`,!'`0```````<J@X_!/+>D,P$W@2`V,
MY20\G^6EWTWB`!"@X8!@@>)``(#B"""-X@`PD^6,,HWE`#"@XP!0H.,$P!#E
M".`0Y0@`@.(L-*#A_SP#XBP\@^$,1*#A##R#X?](!.(^S[_F!#"#X08`4.$`
MP(+E!%""Y0@P@N4,4(+E$"""XNW__QHA/HWB`#"-Y8`PG>4$$(WE<("=Y70@
MG>40L)WE>'"=Y7Q@G>6$P)WE"%"=Y0Q`G>44H)WE$`"-X@,0H.$!``#J";"@
MX0.@H.$!,*#A/."0Y3@0D.4(D+#E"1`AX`@0(>`'@*#A`W"@X0`PH.-T,(#E
M!#"0Y040(>`#X"[@`N`NX`3@+N`&(*#A#&"@X:'/H.&.P(SA`1"1X`P0@>$`
MP)WE"U"@X0``7.$*0*#A`,"@XW`0@.7A__\:!!"=Y?PZG^4(()WE`)"1Y0$(
MD>D@P)'E`R"2X`P@DN"IS:#A$("1Y1B@D>6`PHSA#$"1Y8G"C.$"P)S@"B`H
MX"OAH.$+(`+@"B`BX`3OCN$"P)S@"^^.X1`@G>4I0:#A`$^$X0X`*.`#()+@
M"0``X`@`(.`*()+@"4^$X0`@DN`8`)WE!%`NX`,`D.`,4`7@["V"X`Y0)>`(
M`)#@!0"0X.)=@.`@`)WEL&"=Y0,`D.`.`)#@;.$DX`+@#N`$X"[@#N"0X"@`
MG>5B(:#A`P"0X`0`D.!L02+@!4`$X.7MCN!L023@!`"0X.Y-@.`P`)WE`P"0
MX&P!@.!EP2+@#L`,X`+`+.`,`)#@.,"=Y6[AH.$#P)S@`B"<X&7!+N`$P`S@
MY`V`X&7!+.`,()+@X,V"X$`@G>4#()+@92&"X&11+N``4`7@#E`EX`4@DN!(
M4)WE8`&@X0-0E>`.X)7@9%$@X`Q0!>#L+8+@9%$EX`7@GN#B78[@4."=Y0/@
MGN!DX8[@;$$@X`)`!.``0"3@!.">X%A`G>5B(:#A`T"4X```E.!L02+@!4`$
MX.7MCN!L023@!`"0X.Y-@.!@`)WE`P"0X&P!@.!EP2+@#L`,X`+`+.`,`)#@
M:,"=Y6[AH.$#P)S@`B"<X&7!+N`$P`S@Y`V`X&7!+.`,()+@X,V"X'`@G>4#
M()+@92&"X&11+N``4`7@#E`EX`4@DN!X4)WE8`&@X0-0E>`.X)7@9%$@X`Q0
M!>#L+8+@9%$EX`7@GN#B78[@@."=Y0/@GN!DX8[@;$$@X`)`!.``0"3@!$">
MX(C@G>5B(:#A`^">X```GN!LX2+@!>`.X.5-A.!LX2[@#@"0X.3M@."0`)WE
M`P"0X&P!@.!EP2+@!,`,X`+`+.`,`)#@F,"=Y61!H.$#P)S@`B"<X&7!).`.
MP`S@[@V`X&7!+.`,()+@X,V"X*`@G>4#,)+@;B$DX``@`N`$("+@93&#X`(P
MD^#L+8/@J%"=Y1@XG^5@`:#A`U"5X`10E>!N02#@#$`DX`1`E>`#4);@;E&%
MX+A@G>5LX2#@`N`NX.)-A.`.X)7@8B&@X0-0EN``4)7@P&"=Y6P!(N#D[8[@
M!``@X```E>`#8);@[EV`X&S!AN!D`2+@R&"=Y0X`(.```)S@;N&@X0/`EN`"
MP)S@T&"=Y60A+N`%("+@Y0V`X`(@G.`#P);@9,&,X-A@G>5E02[@X"V"X`!`
M).`$0)S@8`&@X0/`EN`.P)S@X&"=Y>+MA.!E02#@`D`DX`1`G.`#P);@9<&,
MX.A@G>5B42#@#E`EX`50G.!NP:#A`V"6X.Y-A.```);@8N$LX/!@G>4$X"[@
M#N"0X`-@EN#D787@9`$LX&(AAN#X8)WE!0`@X.7MCN``()+@90&@X0-@EN`,
M8);@9,$@X.XM@N``<9WE#L`LX`S`EN#B;8S@`W"7X`A1G>5NP2#@9$&'X`+`
M+.`,P)3@8B&@X0-`E>``0)3@$%&=Y6X!(N#FS8S@!@`@X```E.`#4)7@[$V`
MX&[AA>!F`2+@&%&=Y0P`(.```)[@;,&@X0/@E>`"X)[@(%&=Y68A+.`$("+@
M`B">X`/@E>#D#8#@9N&.X&11+.`H89WE`%`EX.`M@N`%4)[@8`&@X0-@EN`,
MP);@9.$@X#!AG>4"X"[@XEV%X`[@G.`#P);@9,&,X#AAG>5B02#@Y>V.X`5`
M).`$0)S@95&@X0/`EN``P)S@0&&=Y>X-A.!B027@#D`DX`1`G.`#,);@8C&#
MX&XA)>``("+@`B"3X$C!G>7,-9_EX$V$X`/`G.!@`:#A!<"<X&Y1@.%N80#@
M4'&=Y010!>`&4(7A!<"<X`-0E^#D+8+@;E&%X&3A@.%D80#@6'&=Y0+@#N#B
MS8S@!N".X6(AH.$%4)[@`^"7X`#@GN#L#87@9%&"X61A`N`,4`7@8'&=Y090
MA>$.4)7@;.&"X0-PE^!L80+@`.`.X.!=A>!D08?@!N".X03@GN#E;8[@:.&=
MY6`!H.$#X)[@`B">X&SA@.%L00#@<'&=Y07@#N`$X([A`N">X`-PE^!E(8#A
MYDV.X&S!A^!EX0#@>'&=Y08@`N`.((+A9F&@X0S`DN`#()?@`""2X.0-C.!E
MP8;A9>$&X(!QG>4$P`S@#L",X0+@G.`#P)?@9"&&X67!C.``(`+@9%$&X.#M
MCN`%((+A#""2X.[-@N"((9WE8`&@X611@.$#()+@!B"2X)!QG>5D80#@#E`%
MX`90A>$"4)7@`W"7X&XA@.%N80#@9$&'X`P@`N"8<9WE[%V%X`8@@N%LP:#A
M!$"2X`,@E^``()+@Y0V$X&Y!C.%N80S@!4`$X*!QG>4&0(3A`D"4X&4AC.'@
M;83@`W"7X&5!#.``(`+@;N&'X`0@@N$.()+@YNV"X*@AG>5@`:#A`R"2X`P@
MDN!EP8#A94$`X+!QG>4&P`S@!,",X0)`G.`#P)?@9B&`X;AQG>5EP8S@#B`"
MX&91`.#N383@!2""X6[AH.$,P)+@`R"7X``@DN#D#8S@9L&.X691#N#`<9WE
M!,`,X`7`C.$"4)S@`\"7X&0ACN%FP8S@`"`"X&1A#N#@787@!B""X0P@DN#E
MS8+@R"&=Y6`!H.$#()+@`&"@XPX@DN!DX8#AT'&=Y07@#N`$8('E#&"!Y11@
M@>4<8('E9&$`X`;@CN$"X)[@`W"7X&4A@.%E80#@9$&'X`P@`N#8<9WE!B""
MX>SMCN`$0)+@;,&@X0,@E^``()+@90&,X65A#.`.``#@X'&=Y08`@.'N383@
M`@"0X&XAC.$#<)?@;F$,X`0@`N#0,I_EY`V`X&51A^`&((+AZ'&=Y61!H.$%
M()+@X%V"X/!AG>5N(23@`W"7X`S`E^``("+@`B"<X`/`EN!NP8S@^&&=Y>7M
M@N!@(23@!2`BX`(@G.!E4:#A`V"6X`1`EN!@P27@`&*=Y0[`+.`,P)3@`T"6
MX.XM@N!@083@"&*=Y6X!)>`"`"#@XLV,X```E.!B(:#A`V"6X`50EN!N02+@
M$&*=Y0Q`).`$0)7@`U"6X.P-@.`88IWE;E&%X&SA(N``X"[@X$V$X`[@E>!@
M`:#A`U"6X`)0E>`@8IWE;"$@X.3MCN`$("+@`B"5X`-@EN#N78+@;,&&X&0A
M(.`H8IWE#B`BX`(@G.!NX:#A`\"6X`#`G.`P8IWE9`$NX.4M@N`%`"#@``"<
MX`/`EN!DP8S@.&*=Y>)-@.!E`2[@`@`@X```G.!B(:#A`V"6X`[@EN!EP2+@
M0&*=Y>0-@.`$P"S@#,">X`/@EN!EX8[@2&*=Y>!=C.!DP2+@`,`LX`S`GN!@
M`:#A`^"6X`+@GN!08IWE9"$@X.7-C.`%("+@`B">X`/@EN!DX8[@6&*=Y>Q-
M@N!E(2#@#"`BX`(@GN!LP:#A`^"6X`#@GN!@8IWE90$LX.0M@N`$`"#@``">
MX`/@EN!EX8[@:&*=Y>)=@.!D`2S@`@`@X```GN!B(:#A`^"6X`S@GN!P8IWE
M9,$BX`7`+.`,P)[@`^"6X.4-@.!DX8[@96$BX'A"G>4`8";@X,V,X`;@GN!@
M`:#A`T"4X`(@E.!E82#@@$*=Y0Q@)N#L[8[@!B"2X`,PE.!LH8K@"3"3X&S!
M(.#N+8+@#L`LX&4Q@^`,,)/@XCV#X"#`D>4+()+@;H&(X``P@>48H('E$("!
MY0@@@>4L,)_E#`"0X`!@H.,@`('E)&"!Y0`@D^6,,IWE`B`SX``PH.,!```:
MI=^-XO"/O>BW]/_KT)T!`)EY@EJAZ]ENW+P;C];!8LH!RJ#C$$`MZ0S`3>#X
M#XSE@`"@XZGT_^L.>Y_M`""@XP![@.T->Y_M>""`Y0)[@.T,>Y_M!'N`[0Q[
MG^T&>X#M#'N?[0A[@.T,>Y_M"GN`[0Q[@.T0@+WH`2-%9P````")J\WO````
M`/[<NI@`````=E0R$`````#PX=+#`````````````````<J@X_!'+>D,P$W@
MX`^,Y2@PD.4"D*#A+""0Y8G!@^`#`%SA`#"@XP(@T^``4*#A,""0Y0%`H.$T
M$)#ER0^@X0$``"H!()+B`!"AXBPPA>6I/J#A@#&#X0(PD^"@'J'@>`"5Y2C`
MA>4``%#C.("%`C`PA>4T$(7E(0``&C\`6>,Q``#:0)!)XBECH.$!<(;B!W.$
MX`00H.$(,*#A0$"$X@#@D>4$P)'E"`"1Y0P@D>40$('B!`!1X0#@@^4$P(/E
M"`"#Y0P@@^40,(/B\___&@%`H.$%`*#ADOS_ZP<`5.'K__\:!FUFX`:3B>`)
M(*#A!Q"@X0@`H.$M]/_K>)"%Y?"'O>A`<&#B"0!7X0EPH*$X@(7B``"(X`<@
MH.$$$*#A(_3_ZW@PE>4#,(?@0`!3XW@PA>7PA[T8!0"@X0>02>`'0(3@=_S_
MZ\O__^H$<*#AY?__Z@'*H./P02WI#,!-X.@/C.4H,)'E,'"1Y3B`@>*C(:#A
M/R`"XC-OO^8!,(+B`4"@X3@`4^-_$.#C`%"@X3=_O^8"$,CG/0``VD`@8^(`
M$*#C`P"(X-3S_^L$`*#A7/S_ZS@@H.,`$*#C"`"@X<[S_^L$`*#A<'"$Y71@
MA.54_/_K`S#4Y00`H.$`,,7ELC#4X0$PQ>4`,)3E(S2@X0(PQ>4`,)3E`S#%
MY0LPU.4$,,7ENC#4X04PQ>4(,)3E(S2@X08PQ>4(,)3E!S#%Y1,PU.4(,,7E
MLC'4X0DPQ>40,)3E(S2@X0HPQ>40,)3E"S#%Y1LPU.4,,,7ENC'4X0TPQ>48
M,)3E(S2@X0XPQ>48,)3E#S#%Y2,PU.40,,7ELC+4X1$PQ>4@,)3E(S2@X1(P
MQ>4@,)3E$S#%Y?!!O>BI\__J`P"(X#@@8^(`$*#CEO/_Z\;__^H`````````
M``\*X.,?\$#B"#"?Y0,PC^``,)/E[?/_ZH!:```(0"WI"("]Z`$``@`^````
M00````P```!!````$0```$$````G````00```#8```!!`````P```$$````&
M````00```!4```!!````#P```$$````.````00```"8```!!````$P```$$`
M```I````00````(```!!````&0```$$````*````00````L```!!````````
M```````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T
M7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO
M)7,`97AE`"X```!005)?5$5-4`````!005)?4%)/1TY!344`````.@```"5S
M)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$52
M3$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````
M4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,3T)!3%]$14)51P````!0
M05)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-
M4`!005)?1TQ/0D%,7T-,14%.`````#$```!L<V5E:R!F86EL960`````<F5A
M9"!F86EL960`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S
M)7,E<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD
M(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R
M`````'-H;W)T(')E860``"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S
M````)7,E<W1E;7`M)74M)74E<P`````8````<&5R;``````P````4$%2.CI0
M86-K97(Z.E9%4E-)3TX`````,2XP-C,```!5;F%B;&4@=&\@8W)E871E(&-A
M8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H
M92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M
M+0``55-%4@````!54T523D%-10````!414U01$E2`%1-4``O=&UP`````&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C
M:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M
M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A
M8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P
M-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H
M=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@
M)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O
M<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"10
M05)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'
M24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU
M;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R
M:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@
M)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^
M)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H
M"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D[
M"F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R
M7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S
M*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O
M;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@
M34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I
M.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA
M9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI
M.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I
M=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?
M1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#
M04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@
M;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M
M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O
M9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO
M=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D
M;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@[
M"FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@
M/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN
M72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B
M=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@
M=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG
M="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M
M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D
M9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO
M9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T
M<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@
M(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D
M<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@
M<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*
M:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A
M<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q
M("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%
M?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V
M:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=
M(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D
M,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I
M('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I
M('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]
M("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL
M)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@
M*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q
M6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E
M<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF
M("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%2
M7U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E
M9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D
M:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H
M)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R
M(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM
M>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N
M;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC
M;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB
M:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F
M:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A
M9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A
M9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B
M.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C
M:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@
M;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF
M("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME
M>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92![
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D
M:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*
M;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@
M>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN
M9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D
M=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B
M/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET
M=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF
M("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*
M?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@
M/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^
M861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D
M8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<
M,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F
M9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E
M(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D
M(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!0
M05(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E
M($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]
M($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F
M86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(
M*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@
M*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP
M+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R
M86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A
M=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@
M)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I
M>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E
M(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@
M>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;
M17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER
M(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R
M;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"([
M"GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D
M;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K
M("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H
M*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG
M=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@
M)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H
M(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D
M8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H
M95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D
M8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%2
M7T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H
M95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*
M;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@
M)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM
M>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I
M;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T
M96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D
M9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L
M;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D
M<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N
M.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O
M9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345]
M.PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD
M<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W
M9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6
M>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@
M*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN
M="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K
M86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID
M;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC````<$D!`(1&`0``````
M1$<!`$A'`0!D20$`C$8!`&Q)`0``````4$D!`%A)`0```````$-!0TA%```^
M````00````P```!!````$0```$$````G````00```#8```!!`````P```$$`
M```&````00```!4```!!````#P```$$````.````00```"8```!!````$P``
M`$$````I````00````(```!!````&0```$$````*````00````L```!!````
M``````````!XD/]_`0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````H&0$``!D!````````````````
M```````````````````````!````%`,```$````D`P```0```"X#```,````
M!!,!``T```",10$`&0```,B=`0`;````!````!H```#,G0$`'`````0```#U
M_O]OM`$!``4````@"P$`!@```-`$`0`*````J00```L````0````%0``````
M```#````])X!``(```#H`0``%````!$````7````'!$!`!$```#D$`$`$@``
M`#@````3````"````!X````(````^___;P$```#^__]OE!`!`/___V\"````
M\/__;\H/`0``````````````````````````````````````````````````
M``````````````#LG0$````````````0$P$`$!,!`!`3`0`0$P$`$!,!`!`3
M`0`0$P$`$!,!`!`3`0`0$P$`$!,!`!`3`0`0$P$`$!,!`!`3`0`0$P$`$!,!
M`!`3`0`0$P$`$!,!`!`3`0`0$P$`$!,!`!`3`0`0$P$`$!,!`!`3`0`0$P$`
M$!,!`!`3`0`0$P$`$!,!`!`3`0`0$P$`$!,!`!`3`0`0$P$`$!,!`!`3`0`0
M$P$`$!,!`!`3`0`0$P$`$!,!`!`3`0`0$P$`$!,!`!`3`0`0$P$`$!,!`!`3
M`0`0$P$`$!,!`!`3`0`0$P$`$!,!`!`3`0`0$P$`$!,!`!`3`0`0$P$`````
M````````%@$````````````*4$%2+G!M"@````!X20$`1T-#.B`H4F%S<&)I
M86X@,3,N,RXP+3$K<G!I,BD@,3,N,RXP`$$N````865A8FD``20````%-@`&
M!@@!"0$*`A($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%2
M32YE>&ED>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1A
M=&$N<F5L+G)O`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N
M05)-+F%T=')I8G5T97,`````````````````````````````````````````
M````````````````"P````$````"````5`$!`%0!```9```````````````!
M`````````!,````'`````@```'`!`0!P`0``)```````````````!```````
M```F````!P````(```"4`0$`E`$``"````````````````0`````````-```
M`/;__V\"````M`$!`+0!```<`P``!0`````````$````!````#X````+````
M`@```-`$`0#0!```4`8```8````!````!````!````!&`````P````(````@
M"P$`(`L``*D$``````````````$`````````3@```/___V\"````R@\!`,H/
M``#*````!0`````````"`````@```%L```#^__]O`@```)00`0"4$```4```
M``8````"````!`````````!J````"0````(```#D$`$`Y!```#@````%````
M``````0````(````<P````D```!"````'!$!`!P1``#H`0``!0```!8````$
M````"````'P````!````!@````03`0`$$P``#```````````````!```````
M``!W`````0````8````0$P$`$!,``/`"``````````````0````$````@@``
M``$````&`````!8!```6``",+P`````````````0`````````(@````!````
M!@```(Q%`0",10``"```````````````!`````````".`````0````(```"4
M10$`E$4``"A"``````````````0`````````E@````$``'""````O(<!`+R'
M```(````#0`````````$`````````*$````!`````@```,2'`0#$AP``!```
M````````````!`````````"K````#@````,```#(G0$`R(T```0`````````
M``````0````$````MP````\````#````S)T!`,R-```$```````````````$
M````!````,,````!`````P```-"=`0#0C0``&P``````````````"```````
M``#0````!@````,```#LG0$`[(T```@!```&``````````0````(````V0``
M``$````#````])X!`/2.```,`0`````````````$````!````-X````!````
M`P````"@`0``D```&```````````````!`````````#D````"`````,````8
MH`$`&)```"0```````````````@`````````Z0````$````P`````````!B0
M```E```````````````!`````0```/(````#``!P```````````]D```+P``
M`````````````0`````````!`````P``````````````;)````(!````````
,``````$`````````
